@@ -9,22 +9,37 @@ NodeList.prototype.remove = HTMLCollection.prototype.remove = function() {
     }
 }
 
+function isIE() {
+    var ua = window.navigator.userAgent;
+    var msie = ua.indexOf("MSIE ");
+    if (msie > 0 || !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
+        return true;
+    }
+    return false;
+}
 
 document.addEventListener("DOMContentLoaded", function(event) {
     const cookie_alert = document.getElementById("cookie-alert");
     if (!cookie_alert) {
-        return
+        return;
     }
 
-    cookie_alert.addEventListener("animationend", function(ev) {
-        if (ev.type === "animationend") {
-            if (cookie_alert.classList.contains('fade_out')) {
-                 cookie_alert.remove();
-            }
+    if (isIE()) {
+        if (cookie_alert.classList.contains('fade_out')) {
+            cookie_alert.remove();
         }
-    }, false);
+    } else {
+        cookie_alert.addEventListener("animationend", function(ev) {
+            if (ev.type === "animationend") {
+                if (cookie_alert.classList.contains('fade_out')) {
+                    cookie_alert.remove();
+                }
+            }
+        }, false);
+    }
 
-    cookie_alert.querySelector('button.cookie--accept').addEventListener("click", function(event) {
+    var btn = document.getElementsByClassName('cookie--accept');
+    btn.addEventListener("click", function(event) {
         hideCookieConsentDialog(event);
         setCookies();
         addTrackerIframe();
@@ -33,14 +48,18 @@ document.addEventListener("DOMContentLoaded", function(event) {
 
 let hideCookieConsentDialog = function(e) {
     const cookie_alert = document.getElementById("cookie-alert");
-    // check if element exists
-    if (!cookie_alert) { console.warn('Could not find cookie element'); return }
+    const modal_bg = document.getElementById("cookie-modal-bg");
+
+    // check if both elements exists - may not if footer - template is used.
+    if (!cookie_alert) {
+        return;
+    }
 
     e.preventDefault();
     cookie_alert.classList.toggle('fade_out');
-
-    const modal_bg = document.getElementById("cookie-modal-bg");
-    modal_bg.style.display = 'none';
+    if (modal_bg) {
+        modal_bg.style.display = 'none';
+    }
 };
 
 let setCookies = function() {
